@@ -25,6 +25,12 @@ class DataCheckResult:
     def __bool__(self):
         return self.passed
 
+    def __str__(self):
+        return (
+            f"DataCheckResult(passed={self.passed}, "
+            f"result={self.result}, message={self.message})"
+        )
+
     @staticmethod
     def result_type_passed(result_type: ResultType) -> bool:
         return result_type == ResultType.PASSED
